==> opensearch-dashboards-2.19.2-1-x86_64.pkg.tar.zst: usr/share/opensearch-dashboards/src/core/server/ui_settings/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "CURRENT_USER_PLACEHOLDER", {
  enumerable: true,
  get: function () {
    return _utils.CURRENT_USER_PLACEHOLDER;
  }
});
Object.defineProperty(exports, "DeprecationSettings", {
  enumerable: true,
  get: function () {
    return _types.DeprecationSettings;
  }
});
Object.defineProperty(exports, "IUiSettingsClient", {
  enumerable: true,
  get: function () {
    return _types.IUiSettingsClient;
  }
});
Object.defineProperty(exports, "ImageValidation", {
  enumerable: true,
  get: function () {
    return _types.ImageValidation;
  }
});
Object.defineProperty(exports, "InternalUiSettingsServiceSetup", {
  enumerable: true,
  get: function () {
    return _types.InternalUiSettingsServiceSetup;
  }
});
Object.defineProperty(exports, "InternalUiSettingsServiceStart", {
  enumerable: true,
  get: function () {
    return _types.InternalUiSettingsServiceStart;
  }
});
Object.defineProperty(exports, "PublicUiSettingsParams", {
  enumerable: true,
  get: function () {
    return _types.PublicUiSettingsParams;
  }
});
Object.defineProperty(exports, "StringValidation", {
  enumerable: true,
  get: function () {
    return _types.StringValidation;
  }
});
Object.defineProperty(exports, "StringValidationRegex", {
  enumerable: true,
  get: function () {
    return _types.StringValidationRegex;
  }
});
Object.defineProperty(exports, "StringValidationRegexString", {
  enumerable: true,
  get: function () {
    return _types.StringValidationRegexString;
  }
});
Object.defineProperty(exports, "UiSettingScope", {
  enumerable: true,
  get: function () {
    return _types.UiSettingScope;
  }
});
Object.defineProperty(exports, "UiSettingsClient", {
  enumerable: true,
  get: function () {
    return _ui_settings_client.UiSettingsClient;
  }
});
Object.defineProperty(exports, "UiSettingsParams", {
  enumerable: true,
  get: function () {
    return _types.UiSettingsParams;
  }
});
Object.defineProperty(exports, "UiSettingsService", {
  enumerable: true,
  get: function () {
    return _ui_settings_service.UiSettingsService;
  }
});
Object.defineProperty(exports, "UiSettingsServiceOptions", {
  enumerable: true,
  get: function () {
    return _ui_settings_client.UiSettingsServiceOptions;
  }
});
Object.defineProperty(exports, "UiSettingsServiceSetup", {
  enumerable: true,
  get: function () {
    return _types.UiSettingsServiceSetup;
  }
});
Object.defineProperty(exports, "UiSettingsServiceStart", {
  enumerable: true,
  get: function () {
    return _types.UiSettingsServiceStart;
  }
});
Object.defineProperty(exports, "UiSettingsType", {
  enumerable: true,
  get: function () {
    return _types.UiSettingsType;
  }
});
Object.defineProperty(exports, "UserProvidedValues", {
  enumerable: true,
  get: function () {
    return _types.UserProvidedValues;
  }
});
Object.defineProperty(exports, "config", {
  enumerable: true,
  get: function () {
    return _ui_settings_config.config;
  }
});
var _ui_settings_client = require("./ui_settings_client");
var _ui_settings_config = require("./ui_settings_config");
var _ui_settings_service = require("./ui_settings_service");
var _types = require("./types");
var _utils = require("./utils");

==> opensearch-dashboards-3.4.0-1-x86_64.pkg.tar.zst: usr/share/opensearch-dashboards/src/core/server/ui_settings/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "CURRENT_USER_PLACEHOLDER", {
  enumerable: true,
  get: function () {
    return _utils.CURRENT_USER_PLACEHOLDER;
  }
});
Object.defineProperty(exports, "CURRENT_WORKSPACE_PLACEHOLDER", {
  enumerable: true,
  get: function () {
    return _utils.CURRENT_WORKSPACE_PLACEHOLDER;
  }
});
Object.defineProperty(exports, "DeprecationSettings", {
  enumerable: true,
  get: function () {
    return _types.DeprecationSettings;
  }
});
Object.defineProperty(exports, "IUiSettingsClient", {
  enumerable: true,
  get: function () {
    return _types.IUiSettingsClient;
  }
});
Object.defineProperty(exports, "ImageValidation", {
  enumerable: true,
  get: function () {
    return _types.ImageValidation;
  }
});
Object.defineProperty(exports, "InternalUiSettingsServiceSetup", {
  enumerable: true,
  get: function () {
    return _types.InternalUiSettingsServiceSetup;
  }
});
Object.defineProperty(exports, "InternalUiSettingsServiceStart", {
  enumerable: true,
  get: function () {
    return _types.InternalUiSettingsServiceStart;
  }
});
Object.defineProperty(exports, "PublicUiSettingsParams", {
  enumerable: true,
  get: function () {
    return _types.PublicUiSettingsParams;
  }
});
Object.defineProperty(exports, "StringValidation", {
  enumerable: true,
  get: function () {
    return _types.StringValidation;
  }
});
Object.defineProperty(exports, "StringValidationRegex", {
  enumerable: true,
  get: function () {
    return _types.StringValidationRegex;
  }
});
Object.defineProperty(exports, "StringValidationRegexString", {
  enumerable: true,
  get: function () {
    return _types.StringValidationRegexString;
  }
});
Object.defineProperty(exports, "UiSettingScope", {
  enumerable: true,
  get: function () {
    return _types.UiSettingScope;
  }
});
Object.defineProperty(exports, "UiSettingsClient", {
  enumerable: true,
  get: function () {
    return _ui_settings_client.UiSettingsClient;
  }
});
Object.defineProperty(exports, "UiSettingsParams", {
  enumerable: true,
  get: function () {
    return _types.UiSettingsParams;
  }
});
Object.defineProperty(exports, "UiSettingsService", {
  enumerable: true,
  get: function () {
    return _ui_settings_service.UiSettingsService;
  }
});
Object.defineProperty(exports, "UiSettingsServiceOptions", {
  enumerable: true,
  get: function () {
    return _ui_settings_client.UiSettingsServiceOptions;
  }
});
Object.defineProperty(exports, "UiSettingsServiceSetup", {
  enumerable: true,
  get: function () {
    return _types.UiSettingsServiceSetup;
  }
});
Object.defineProperty(exports, "UiSettingsServiceStart", {
  enumerable: true,
  get: function () {
    return _types.UiSettingsServiceStart;
  }
});
Object.defineProperty(exports, "UiSettingsType", {
  enumerable: true,
  get: function () {
    return _types.UiSettingsType;
  }
});
Object.defineProperty(exports, "UserProvidedValues", {
  enumerable: true,
  get: function () {
    return _types.UserProvidedValues;
  }
});
Object.defineProperty(exports, "config", {
  enumerable: true,
  get: function () {
    return _ui_settings_config.config;
  }
});
var _ui_settings_client = require("./ui_settings_client");
var _ui_settings_config = require("./ui_settings_config");
var _ui_settings_service = require("./ui_settings_service");
var _types = require("./types");
var _utils = require("./utils");
